@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 10809 2018-03-04 09:29:56Z Lavender $
+# $Id: cms_dumpdata.py 11414 2019-03-30 06:35:59Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,18 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-03-04 17:29:56 +0800 (週日, 04 三月 2018) $
-# $Revision: 10809 $
+# $Date: 2019-03-30 15:35:59 +0900 (週六, 30 三月 2019) $
+# $Revision: 11414 $
 
 import os
 import sys
 import json
+import six
 
-from StringIO import StringIO
+if six.PY2:
+    from StringIO import StringIO
+else:
+    from io import StringIO
 
 from django.core.management.base import BaseCommand
 from django.core import serializers
