@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11386 2019-03-13 08:54:27Z Lavender $
+# $Id: setup.py 11391 2019-03-21 07:46:45Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,30 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-13 17:54:27 +0900 (週三, 13 三月 2019) $
-# $Revision: 11386 $
+# $Date: 2019-03-21 16:46:45 +0900 (週四, 21 三月 2019) $
+# $Revision: 11391 $
+
 import os
 import sys
 import logging
 import shutil
 import json
 import argparse
+import traceback
+
+try:
+    import colorama 
+except Exception as e:
+    os.system("pip install colorama==0.4.1")
+    import colorama
+    
+colorama.init()
+
+try:
+    from termcolor import colored, cprint
+except Exception as e:
+    os.system("pip install termcolor==1.1.0")
+    from termcolor import colored, cprint
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -64,7 +80,7 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
     if not staticDir:
         staticDir = os.path.join(baseDir,'static')
        
-    logger.info("-----Start copy templates-----")
+    logger.info(colored("-----Start copy templates-----", "yellow"))
     if not os.path.exists(staticDir):
         os.mkdir(staticDir)
     if not os.path.exists(templateDir):
@@ -98,7 +114,8 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                 continue
            
             if os.path.isfile(dst):
-                logger.error("%s exists. failed to copy file." % dst)
+                logger.error(
+                    colored("%s exists. failed to copy file." % dst, "red"))
             else:
                 shutil.copyfile(origin, dst)
                 logger.info("Succeed to copy file to %s." % dst)
@@ -125,7 +142,8 @@ def canAddPlugin(pkgName, pluginName):
                
 def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate, baseDir,
                   wizard=False, createProject=False):
-    logger.info("-----Start write and backup settings.py-----")
+    logger.info(
+        colored("-----Start write and backup settings.py-----", "yellow"))
     def getCMSTemplates():
         templates = []
        
@@ -148,10 +166,10 @@ def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate, baseDir,
     settingsDir = os.path.dirname(settingsPath)
     bak = os.path.join(settingsDir, 'settings.py.bak')
     if os.path.isfile(bak):
-        logger.error("%s exists. failed to backup file." % bak)
+        logger.error(colored("%s exists. failed to backup file." % bak, "red"))
         return 
     shutil.copyfile(settingsPath, bak)
-    logger.info("Succeed to backup settings.py to %s." % bak)
+    logger.info(colored("Succeed to backup settings.py to %s." % bak, "yellow"))
                
     with open(settingsPath, 'r') as settings:
         content = settings.read()
@@ -237,20 +255,20 @@ else:
         settings.write(content)
            
                
-    logger.info("Succeed to write settings.py")
+    logger.info(colored("Succeed to write settings.py", "yellow"))
                
 def loadData(baseDir, language):
-    logger.info("-----Start load data-----")
+    logger.info(colored("-----Start load data-----", "yellow"))
     data = os.path.join(".", 'fixtures', 'initial_data.json')
     result = os.system("%s manage.py migrate" % sys.executable)
     if not result == 0:
-        logger.error("Can not migrate db.")
+        logger.error(colored("Can not migrate db.", "red"))
         return False
        
     result = os.system("%s manage.py loaddata \"%s\"" % (sys.executable, data))
    
     if not result == 0:
-        logger.error("Can not loaddata.")
+        logger.error(colored("Can not loaddata.", "red"))
         return False
    
     from cms.models.pagemodel import Page
@@ -274,200 +292,250 @@ def loadData(baseDir, language):
     return True
        
 if __name__ == "__main__":
-    parser = argparse.ArgumentParser(description='Path to Project')
-    parser.add_argument(
-        'path', metavar='path', type=str, help='path', nargs='+')
-       
-    parser.add_argument(
-        '-w', '--wizard', 
-        action='store_true',
-        help="Run the configuration wizard")   
-   
-    args = parser.parse_args()
-   
-    wizard = args.wizard
-    mode = 'user'
-    
-    if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
-        with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
-            data = json.loads(f.read())
-            
-        cmsVersion = data["DjangoCMSVersion"]
-    else:
-        cmsVersion = '3.5.1'
-    
-    if cmsVersion.startswith("3.4"):
-        installVersion = "0.9.7"
-    elif cmsVersion.startswith("3.5"):
-        installVersion = "1.0.0"
-    else:
-        installVersion = "1.0.0"
-       
-    path = " ".join(args.path) 
-   
-    settingsPath = findSettings(path)
-   
-    createProject = False
-   
-    if not settingsPath:
-        if sys.version_info.major == 3:
-            print()
-            projectName = input(
-                ("Django project not found. "
-                 "Auto create one by djangocms-installer==%s."
-                 "\nPlease input a project name:") % installVersion)
-        else:
-            print
-            projectName = raw_input(
-                ("Django project not found. "
-                 "Auto create one by djangocms-installer==%s."
-                 "\nPlease input a project name:") % installVersion)
-        
-        result = os.system(
-            "pip install djangocms-installer==%s" % installVersion)
-        
-        if result != 0:
-            logger.error(
-                "Unable to run pip, please check your pip configuration, "
-                "maybe it is because you didn't set python in system PATH "
-                "or broken network connection.")
-            sys.exit(1)
-       
-        path = os.path.join(path, projectName)
-       
-        if wizard:
-            result = os.system(
-                "djangocms -f -p \"%s\" \"%s\" -w" % (path, projectName))
-        else:
-            result = os.system(
-                "djangocms -f -p \"%s\" \"%s\"" % (path, projectName))
-       
-        createProject = True
+    try:
+        parser = argparse.ArgumentParser(description='Path to Project')
+        parser.add_argument(
+            "path", metavar='path', 
+            type=str,  nargs='?', default=".",
+            help="Path to project, default is '.'"
+        )
            
-        if not result == 0:
-            print
-            logger.error(
-                "Please check your environment "
-                "which djangocms-installer is installed or "
-                "upgrade to the latest.")
-            sys.exit(1)
+        parser.add_argument(
+            '-w', '--wizard', 
+            action='store_true',
+            help="Run the configuration wizard")   
+       
+        args = parser.parse_args()
+       
+        wizard = args.wizard
+        mode = 'user'
+        
+        if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
+            with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
+                data = json.loads(f.read())
+                
+            cmsVersion = data["DjangoCMSVersion"]
+        else:
+            cmsVersion = '3.5.1'
+        
+        if cmsVersion.startswith("3.4"):
+            installVersion = "0.9.7"
+        elif cmsVersion.startswith("3.5"):
+            installVersion = "1.0.0"
+        else:
+            installVersion = "1.0.0"
            
+        path = args.path
+       
         settingsPath = findSettings(path)
-    else:
-        path = os.path.dirname(os.path.dirname(settingsPath))
-   
-    settingModule = os.path.splitext(settingsPath[len(path) + 1:])[0]
-    settingModule = settingModule.replace("/", ".")
-    settingModule = settingModule.replace("\\", ".")
-   
-    sys.path.append(path)
-    os.environ['DJANGO_SETTINGS_MODULE'] = settingModule
-   
-    import django
-   
-    try:
-        import cms
-    except Exception as e:
-        os.system("pip install django-cms==%s" % cmsVersion)
-        import cms
-
-    import cms
-    
-    if cms.__version__.startswith('3.5'):
-        try:
-            import cmsplugin_filer_image
-        except Exception as e:
-            os.system("pip install cmsplugin-filer==1.1.3")
-            import cms
+       
+        createProject = False
+       
+        if not settingsPath:
+            if sys.version_info.major == 3:
+                print()
+                projectName = input(
+                    ("Django project not found. "
+                     "Auto create one by djangocms-installer==%s."
+                     "\nPlease input a project name:") % installVersion)
+            else:
+                print
+                projectName = raw_input(
+                    ("Django project not found. "
+                     "Auto create one by djangocms-installer==%s."
+                     "\nPlease input a project name:") % installVersion)
             
-    import djangocms_text_ckeditor
-    if not djangocms_text_ckeditor.__version__.startswith("3.5"):
-        try:
-            os.system("pip install -U djangocms_text_ckeditor==3.5.3")
-        except Exception as e:
-            logger.error("Can't install djangocms_text_ckeditor==3.5.3")
-            sys.exit(1)
-       
-    cmsVersion = cms.__version__.split('.')
-   
-    cms34 = True
-    try:
-        if int(cmsVersion[0]) <= 3 and int(cmsVersion[1]) <= 4:
-            cms34 = True
-        else:
-            cms34 = False
-    except Exception as e:
-        cms34 = False
-       
-    if cms34:
-        if not (django.VERSION[0] == 1 and django.VERSION[1] <= 10):
-            logger.error(
-                "Your installed Django above 1.10 which is not supported by "
-                "Django CMS 3.4 yet, please reinstall Django or you may "
-                "encounter some issues while using Django CMS.")
-            sys.exit(1)
-    django.setup()
-   
-    from django.conf import settings
-   
-    baseDir = settings.BASE_DIR
-   
-    apps = [
-        'cms',
-        'menus',
-        'sekizai',
-        'treebeard',
-        'djangocms_text_ckeditor',
-        'filer',
-        'easy_thumbnails',
-    ]
-   
-    endSetup = False
-    for app in apps:
-        if not app in settings.INSTALLED_APPS:
-            logger.error("The app doesn't be included in INSTALLED_APPS: %s" % 
-                         app)
-            endSetup = True
-   
-    if endSetup:
-        print
-        logger.error("The project does not support django cms. "
-                     "Please follow the instructions at "
-                     "http://docs.django-cms.org/en/stable/how_to/install.html")
-        sys.exit(1)
+            result = os.system(
+                "pip install djangocms-installer==%s" % installVersion)
+            
+            if result != 0:
+                logger.error(colored(
+                    "Unable to run pip, please check your pip configuration, "
+                    "maybe it is because you didn't set python in system PATH "
+                    "or broken network connection.", "red"))
+                sys.exit(1)
            
-    try:
-        templateDir = settings.TEMPLATES[0]['DIRS'][0]
+            path = os.path.join(path, projectName)
+           
+            if wizard:
+                result = os.system(
+                    "djangocms -f -p \"%s\" \"%s\" -w" % (path, projectName))
+            else:
+                result = os.system(
+                    "djangocms -f -p \"%s\" \"%s\"" % (path, projectName))
+           
+            createProject = True
+               
+            if not result == 0:
+                print("")
+                logger.error(colored(
+                    "Please check your environment "
+                    "which djangocms-installer is installed or "
+                    "upgrade to the latest.", "red"))
+                sys.exit(1)
+               
+            settingsPath = findSettings(path)
+        else:
+            path = os.path.dirname(os.path.dirname(settingsPath))
+       
+        settingModule = os.path.splitext(settingsPath[len(path) + 1:])[0]
+        settingModule = settingModule.replace("/", ".")
+        settingModule = settingModule.replace("\\", ".")
+       
+        sys.path.append(path)
+        os.environ['DJANGO_SETTINGS_MODULE'] = settingModule
+       
+        import django
+       
+        try:
+            import cms
+        except Exception as e:
+            os.system("pip install django-cms==%s" % cmsVersion)
+            import cms
+
+        import cms
+        
+        if cms.__version__.startswith('3.5'):
+            try:
+                import cmsplugin_filer_image
+            except Exception as e:
+                os.system("pip install cmsplugin-filer==1.1.3")
+                import cms
+                
+        import djangocms_text_ckeditor
+        if not djangocms_text_ckeditor.__version__.startswith("3.5"):
+            try:
+                os.system("pip install -U djangocms_text_ckeditor==3.5.3")
+            except Exception as e:
+                logger.error(
+                    colored("Can't install djangocms_text_ckeditor==3.5.3", 
+                            "red"))
+                sys.exit(1)
+           
+        cmsVersion = cms.__version__.split('.')
+       
+        cms34 = True
+        try:
+            if int(cmsVersion[0]) <= 3 and int(cmsVersion[1]) <= 4:
+                cms34 = True
+            else:
+                cms34 = False
+        except Exception as e:
+            cms34 = False
+           
+        if cms34:
+            if not (django.VERSION[0] == 1 and django.VERSION[1] <= 10):
+                logger.error(colored(
+                    "Your installed Django above 1.10 which is not supported by "
+                    "Django CMS 3.4 yet, please reinstall Django or you may "
+                    "encounter some issues while using Django CMS.", "red"))
+                sys.exit(1)
+        django.setup()
+       
+        from django.conf import settings
+       
+        baseDir = settings.BASE_DIR
+       
+        apps = [
+            'cms',
+            'menus',
+            'sekizai',
+            'treebeard',
+            'djangocms_text_ckeditor',
+            'filer',
+            'easy_thumbnails',
+        ]
+       
+        endSetup = False
+        for app in apps:
+            if not app in settings.INSTALLED_APPS:
+                logger.error(
+                    colored(
+                    "The app doesn't be included in INSTALLED_APPS: %s" % 
+                    app, "red"))
+                endSetup = True
+       
+        if endSetup:
+            print("")
+            logger.error(
+                colored("The project does not support django cms. "
+                "Please follow the instructions at "
+                "http://docs.django-cms.org/en/stable/how_to/install.html", 
+                "red"))
+            sys.exit(1)
+               
+        try:
+            templateDir = settings.TEMPLATES[0]['DIRS'][0]
+        except Exception as e:
+            templateDir = None
+       
+        try:
+            staticDir = settings.STATICFILES_DIRS[0]
+        except Exception as e:
+            staticDir = None
+       
+        copyToPath(baseDir, templateDir, staticDir, mode)
+       
+        if hasattr(settings, "CMS_TEMPLATES"):
+            hasCmsTemplate = True
+        else:
+            hasCmsTemplate = False
+           
+        writeSettings(settingsPath, 
+            templateDir, staticDir, hasCmsTemplate, baseDir,
+            wizard=wizard, createProject=createProject)
+           
+        os.chdir(baseDir)
+           
+        success = loadData(baseDir, settings.LANGUAGE_CODE)
+        if not success:
+            print("")
+            logger.error(
+                colored("Please check the project's db was migrated.", "red"))
+        else:
+            attrs=['bold']
+            print("")
+            
+            logger.info(
+                colored(
+                    "Get into ", "yellow") +
+                colored("\"%s\"" % path, "white", attrs=['bold',]) +
+                colored(" directory and type ", "yellow") +
+                colored(
+                    "\"python manage.py runserver\"", "white", 
+                    attrs=['bold',]) +
+                colored(" to start your project" , "yellow")
+            )
+                        
+            if createProject:
+                logger.info(
+                    colored(
+                        "Please enter ", "yellow") +
+                    colored("http://localhost:8000/?edit", "white",  
+                        attrs=['bold',]) +
+                    colored(
+                        " to show CMS toolbar. Default super user is ", 
+                        "yellow") +
+                    colored(
+                        "'admin' password: 'admin'.", "white", attrs=['bold',])
+                )
+                
     except Exception as e:
-        templateDir = None
-   
-    try:
-        staticDir = settings.STATICFILES_DIRS[0]
-    except Exception as e:
-        staticDir = None
-   
-    copyToPath(baseDir, templateDir, staticDir, mode)
-   
-    if hasattr(settings, "CMS_TEMPLATES"):
-        hasCmsTemplate = True
-    else:
-        hasCmsTemplate = False
-       
-    writeSettings(settingsPath, 
-        templateDir, staticDir, hasCmsTemplate, baseDir,
-        wizard=wizard, createProject=createProject)
-       
-    os.chdir(baseDir)
-       
-    success = loadData(baseDir, settings.LANGUAGE_CODE)
-    if not success:
-        print
-        logger.error("Please check the project's db was migrated.")
-    else:
-        print 
-        logger.info("Get into \"%s\" directory and type"
-                    " \"python manage.py runserver\" to start your project" % 
-                    path)
+        print("")
+        logger.error(colored("ERROR MESSAGE:", "red"))
+        traceback.print_exc()
+        print("")
+        logger.error(colored(
+            "If you encounter \"django.db.utils.OperationalError: "
+            "Problem installing fixtures: no such table: cms_page__old\" "
+            "or \"sqlite3.OperationalError: no such table: "
+            "cms_cmsplugin__old\", something with \"__old\", "
+            "this caused by Django's issue. Please see link: ", "red"))
+        logger.error(
+            colored("https://github.com/django/django/pull/"
+            "10733/commits/c8ffdbe514b55ff5c9a2b8cb8bbdf2d3978c188f", "yellow"))
+        logger.error(
+            colored("to modify your schema.py to fix this problem.", "red"))
     try:
         import json
         if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
